@@ -12,10 +12,29 @@ has 'log' => (
 );
 sub logger {
 	my $self=shift;
+	my $category=shift; 
+	if (defined $category)
+	{
+		return Log::Any->get_logger(category=>$category);
+	}
 	return $self->log;
 }
 1;
 
+__END__
+
+=pod
+
+=encoding UTF-8
+
+=head1 NAME
+
+MooX::Log::Any - Role to add Log::Any
+
+=head1 VERSION
+
+version 0.003
+
 =head1 SYNOPSIS
 
     package MyApp;
@@ -32,7 +51,7 @@ sub logger {
 =head1 DESCRIPTION
 
 A logging role building a very lightweight wrapper to L<Log::Any> for use with your L<Moo> or L<Moose> classes.
-Connectibng a Log::Any::Adapter should be performed prior to logging the first log message, otherwise nothing will happen, just like with Log::Any
+Connecting a Log::Any::Adapter should be performed prior to logging the first log message, otherwise nothing will happen, just like with Log::Any
 
 Using the logger within a class is as simple as consuming a role:
 
@@ -47,7 +66,6 @@ Using the logger within a class is as simple as consuming a role:
 
 The logger needs to be setup before using the logger, which could happen in the main application:
 
-
     package main;
     use Log::Any::Adapter;
     # Send all logs to Log::Log4perl
@@ -58,9 +76,6 @@ The logger needs to be setup before using the logger, which could happen in the
     $myclass->log->info("In my class"); # Access the log of the object
     $myclass->dummy;                    # Will log "Dummy log entry"
 
-
-
-
 =head1 ACCESSORS
 
 =head2 log
@@ -79,7 +94,6 @@ roles/systems like L<MooseX::Log::LogDispatch> this can be thought of as a commo
     $self->logger->debug("Something is fishy here");  # logs a debug message
   }
 
-
 =head2 logger([$category])
 
 This is an alias for log.
@@ -88,26 +102,36 @@ This is an alias for log.
 
 L<Log::Any>, L<Moose>, L<Moo>
 
-=head1 BUGS AND LIMITATIONS
-
-Please report any bugs or feature requests to
-C<bug-moosex-log4perl@rt.cpan.org>, or through the web interface at
-L<http://rt.cpan.org>.
-
-Or come bother us in C<#moose> on C<irc.perl.org>.
-
-=head1 AUTHOR
-
-Roland Lammel C<< <lammel@cpan.org> >>
+=head2 Inspired by
 
 Inspired by the work by Chris Prather C<< <perigrin@cpan.org> >> and Ash
 Berlin C<< <ash@cpan.org> >> on L<MooseX::LogDispatch> and Roland Lammel C<< <lammel@cpan.org> >>
+
+=head1 BUGS AND LIMITATIONS
+
+Please report any bugs or feature requests through github 
+L<https://github.com/cazador481/MooX-Log-Any>.
+
 =head1 CONTRIBUTORS
 
 In alphabetical order:
 
+Jens Rehsack C<< rehsack@gmail.com> >>
+
 =over 2
 
-
-=back
+=back 
 ;
+
+=head1 AUTHOR
+
+Edward Ash <eddie+cpan@ashfamily.net>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2013 by Edward Ash.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
